import { Component, OnInit } from '@angular/core';
import { Observable } from 'rxjs';
import { AuditMetadata } from '../models/audit-metadata';
import { Store } from '@ngrx/store';
import { GlobalState } from '@app/core/state';
import * as selectors from '../store/selectors';
import { StartLoadingAudit } from '../store/actions';

@Component({
  selector: 'cse-dars-metadata-table',
  templateUrl: './metadata-table.component.html',
  styleUrls: ['./metadata-table.component.scss'],
})
export class DarsMetadataTableComponent implements OnInit {
  public metadata$: Observable<AuditMetadata[]>;
  public programMetadata$: Observable<AuditMetadata[]>;
  public whatIfMetadata$: Observable<AuditMetadata[]>;
  public displayedColumns = [
    'view',
    'school',
    'program',
    'honors',
    'plan',
    'status',
    'download',
  ];

  constructor(private store: Store<GlobalState>) {}

  public ngOnInit() {
    this.programMetadata$ = this.store.select(selectors.programMetadata);
    this.whatIfMetadata$ = this.store.select(selectors.whatIfMetadata);
  }

  public openAudit(metadata: AuditMetadata) {
    this.store.dispatch(new StartLoadingAudit(metadata));
  }
}
